==============
Aldryn Gallery
==============

Aldryn Gallery is build uppon the principle of plugin-in-plugin which django-cms provides
since version 3.0.

The gallery requires **jQuery** and `classjs <https://github.com/finalangel/classjs-plugins>`_ cl.gallery.
